export(audit_plan)
importFrom(reformulas,findbars,nobars)
importFrom(stats,setNames)
export(statwitness)
export(statwitness_repeated)
export(witness_registry)
S3method(plot,statwitness_audit)
S3method(print,statwitness_audit)
S3method(print,summary.statwitness_audit)
S3method(summary,statwitness_audit)
