library(statwitness)

dat <- transform(
  mtcars,
  transmission = factor(am, labels = c("automatic", "manual"))
)

plan <- audit_plan(
  mpg ~ transmission + wt + hp,
  data = dat,
  focus = transmission
)
print(plan)

audit <- statwitness(
  mpg ~ transmission + wt + hp,
  data = dat,
  focus = transmission
)
print(audit, details = TRUE)
summary(audit)
