# Your model: random intercept for rater and an omnibus interaction audit.
# Requires install.packages("lme4").

audit <- statwitness::statwitness(
  score ~ criterion * model + (1 | rater),
  data = dataset,
  focus = "criterion:model"
)

print(audit, details = TRUE)

# Repeated-measures ANOVA alternative for a complete long-format design.
# Requires install.packages("afex").

rm_audit <- statwitness::statwitness_repeated(
  data = dataset,
  outcome = "score",
  id = "rater",
  within = c("criterion", "model"),
  focus = "criterion:model"
)
