test_that("Cox model receives survival-specific tests", {
  skip_if_not_installed("survival")
  dat <- survival::lung
  dat$status01 <- as.integer(dat$status == 2)
  out <- statwitness(
    survival::Surv(time, status01) ~ age + sex,
    data = dat,
    focus = "age",
    exclude = "factor_label_invariance"
  )
  expect_identical(out$model_class, "coxph")
  expect_true(any(out$tests$id == "survival_time_scaling"))
  expect_true(any(out$tests$id == "cox_ph_assumption"))
})
